
<!---
FrozenIsBool True
-->

##Example

Let's create an empty class, which will automatically receive special attributes from the decorating ClassorClass specially the NameStr, that should be the ClassStr without the TypeStr in the end.